==> ibus-qt_1.3.0-0maemo2.tar.gz: ibus-qt-1.3.0/CPackSourceConfig.cmake <==
# This file will be configured to contain variables for CPack. These variables
# should be set in the CMake list file of the project before CPack module is
# included. Example variables are:
#   CPACK_GENERATOR                     - Generator used to create package
#   CPACK_INSTALL_CMAKE_PROJECTS        - For each project (path, name, component)
#   CPACK_CMAKE_GENERATOR               - CMake Generator used for the projects
#   CPACK_INSTALL_COMMANDS              - Extra commands to install components
#   CPACK_INSTALL_DIRECTORIES           - Extra directories to install
#   CPACK_PACKAGE_DESCRIPTION_FILE      - Description file for the package
#   CPACK_PACKAGE_DESCRIPTION_SUMMARY   - Summary of the package
#   CPACK_PACKAGE_EXECUTABLES           - List of pairs of executables and labels
#   CPACK_PACKAGE_FILE_NAME             - Name of the package generated
#   CPACK_PACKAGE_ICON                  - Icon used for the package
#   CPACK_PACKAGE_INSTALL_DIRECTORY     - Name of directory for the installer
#   CPACK_PACKAGE_NAME                  - Package project name
#   CPACK_PACKAGE_VENDOR                - Package project vendor
#   CPACK_PACKAGE_VERSION               - Package project version
#   CPACK_PACKAGE_VERSION_MAJOR         - Package project version (major)
#   CPACK_PACKAGE_VERSION_MINOR         - Package project version (minor)
#   CPACK_PACKAGE_VERSION_PATCH         - Package project version (patch)

# There are certain generator specific ones

# NSIS Generator:
#   CPACK_PACKAGE_INSTALL_REGISTRY_KEY  - Name of the registry key for the installer
#   CPACK_NSIS_EXTRA_UNINSTALL_COMMANDS - Extra commands used during uninstall
#   CPACK_NSIS_EXTRA_INSTALL_COMMANDS   - Extra commands used during install


SET(CPACK_BINARY_BUNDLE "")
SET(CPACK_BINARY_CYGWIN "")
SET(CPACK_BINARY_DEB "")
SET(CPACK_BINARY_DRAGNDROP "")
SET(CPACK_BINARY_NSIS "")
SET(CPACK_BINARY_OSXX11 "")
SET(CPACK_BINARY_PACKAGEMAKER "")
SET(CPACK_BINARY_RPM "")
SET(CPACK_BINARY_STGZ "")
SET(CPACK_BINARY_TBZ2 "")
SET(CPACK_BINARY_TGZ "")
SET(CPACK_BINARY_TZ "")
SET(CPACK_BINARY_ZIP "")
SET(CPACK_CMAKE_GENERATOR "Unix Makefiles")
SET(CPACK_COMPONENTS_ALL "")
SET(CPACK_COMPONENT_UNSPECIFIED_HIDDEN "TRUE")
SET(CPACK_COMPONENT_UNSPECIFIED_REQUIRED "TRUE")
SET(CPACK_GENERATOR "TGZ")
SET(CPACK_IGNORE_FILES "/\\.git/;\\.gitignore$;/CMakeFiles/;/_CPack_Packages/;cmake_install.cmake;CMakeCache.txt$;install_manifest.txt$;Makefile$;Source\\.tar\\.gz$;Linux\\.tar\\.gz$;moc_.*\\.cxx$;\\.so$;\\.so\\.*;ibus-test$;/rpm/;ibus-qt\\.spec$;CPackSourceConfig\\.cmake$;CPackConfig\\.cmake$;docs/Doxyfile$;docs/man;docs/html;build/")
SET(CPACK_INSTALLED_DIRECTORIES "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo;/")
SET(CPACK_INSTALL_CMAKE_PROJECTS "")
SET(CPACK_INSTALL_PREFIX "/usr")
SET(CPACK_MODULE_PATH "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/cmake")
SET(CPACK_NSIS_DISPLAY_NAME "ibus-qt 1.3.0")
SET(CPACK_NSIS_INSTALLER_ICON_CODE "")
SET(CPACK_NSIS_INSTALLER_MUI_ICON_CODE "")
SET(CPACK_OUTPUT_CONFIG_FILE "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/CPackConfig.cmake")
SET(CPACK_PACKAGE_DEFAULT_LOCATION "/")
SET(CPACK_PACKAGE_DESCRIPTION_FILE "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericDescription.txt")
SET(CPACK_PACKAGE_DESCRIPTION_SUMMARY "ibus-qt built using CMake")
SET(CPACK_PACKAGE_FILE_NAME "ibus-qt-1.3.0-Source")
SET(CPACK_PACKAGE_INSTALL_DIRECTORY "ibus-qt 1.3.0")
SET(CPACK_PACKAGE_INSTALL_REGISTRY_KEY "ibus-qt 1.3.0")
SET(CPACK_PACKAGE_NAME "ibus-qt")
SET(CPACK_PACKAGE_RELOCATABLE "true")
SET(CPACK_PACKAGE_VENDOR "Humanity")
SET(CPACK_PACKAGE_VERSION "1.3.0")
SET(CPACK_PACKAGE_VERSION_MAJOR "1")
SET(CPACK_PACKAGE_VERSION_MINOR "3")
SET(CPACK_PACKAGE_VERSION_PATCH "0")
SET(CPACK_RESOURCE_FILE_LICENSE "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/COPYING")
SET(CPACK_RESOURCE_FILE_README "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericDescription.txt")
SET(CPACK_RESOURCE_FILE_WELCOME "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericWelcome.txt")
SET(CPACK_SET_DESTDIR "ON")
SET(CPACK_SOURCE_CYGWIN "")
SET(CPACK_SOURCE_GENERATOR "TGZ")
SET(CPACK_SOURCE_IGNORE_FILES "/\\.git/;\\.gitignore$;/CMakeFiles/;/_CPack_Packages/;cmake_install.cmake;CMakeCache.txt$;install_manifest.txt$;Makefile$;Source\\.tar\\.gz$;Linux\\.tar\\.gz$;moc_.*\\.cxx$;\\.so$;\\.so\\.*;ibus-test$;/rpm/;ibus-qt\\.spec$;CPackSourceConfig\\.cmake$;CPackConfig\\.cmake$;docs/Doxyfile$;docs/man;docs/html;build/")
SET(CPACK_SOURCE_INSTALLED_DIRECTORIES "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo;/")
SET(CPACK_SOURCE_OUTPUT_CONFIG_FILE "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/CPackSourceConfig.cmake")
SET(CPACK_SOURCE_PACKAGE_FILE_NAME "ibus-qt-1.3.0-Source")
SET(CPACK_SOURCE_TBZ2 "")
SET(CPACK_SOURCE_TGZ "")
SET(CPACK_SOURCE_TOPLEVEL_TAG "Linux-Source")
SET(CPACK_SOURCE_TZ "")
SET(CPACK_SOURCE_ZIP "")
SET(CPACK_STRIP_FILES "")
SET(CPACK_SYSTEM_NAME "Linux")
SET(CPACK_TOPLEVEL_TAG "Linux-Source")

==> ibus-qt_1.3.1-1maemo2.tar.gz: ibus-qt-1.3.1/CPackSourceConfig.cmake <==
# This file will be configured to contain variables for CPack. These variables
# should be set in the CMake list file of the project before CPack module is
# included. Example variables are:
#   CPACK_GENERATOR                     - Generator used to create package
#   CPACK_INSTALL_CMAKE_PROJECTS        - For each project (path, name, component)
#   CPACK_CMAKE_GENERATOR               - CMake Generator used for the projects
#   CPACK_INSTALL_COMMANDS              - Extra commands to install components
#   CPACK_INSTALL_DIRECTORIES           - Extra directories to install
#   CPACK_PACKAGE_DESCRIPTION_FILE      - Description file for the package
#   CPACK_PACKAGE_DESCRIPTION_SUMMARY   - Summary of the package
#   CPACK_PACKAGE_EXECUTABLES           - List of pairs of executables and labels
#   CPACK_PACKAGE_FILE_NAME             - Name of the package generated
#   CPACK_PACKAGE_ICON                  - Icon used for the package
#   CPACK_PACKAGE_INSTALL_DIRECTORY     - Name of directory for the installer
#   CPACK_PACKAGE_NAME                  - Package project name
#   CPACK_PACKAGE_VENDOR                - Package project vendor
#   CPACK_PACKAGE_VERSION               - Package project version
#   CPACK_PACKAGE_VERSION_MAJOR         - Package project version (major)
#   CPACK_PACKAGE_VERSION_MINOR         - Package project version (minor)
#   CPACK_PACKAGE_VERSION_PATCH         - Package project version (patch)

# There are certain generator specific ones

# NSIS Generator:
#   CPACK_PACKAGE_INSTALL_REGISTRY_KEY  - Name of the registry key for the installer
#   CPACK_NSIS_EXTRA_UNINSTALL_COMMANDS - Extra commands used during uninstall
#   CPACK_NSIS_EXTRA_INSTALL_COMMANDS   - Extra commands used during install


SET(CPACK_BINARY_BUNDLE "")
SET(CPACK_BINARY_CYGWIN "")
SET(CPACK_BINARY_DEB "")
SET(CPACK_BINARY_DRAGNDROP "")
SET(CPACK_BINARY_NSIS "")
SET(CPACK_BINARY_OSXX11 "")
SET(CPACK_BINARY_PACKAGEMAKER "")
SET(CPACK_BINARY_RPM "")
SET(CPACK_BINARY_STGZ "")
SET(CPACK_BINARY_TBZ2 "")
SET(CPACK_BINARY_TGZ "")
SET(CPACK_BINARY_TZ "")
SET(CPACK_BINARY_ZIP "")
SET(CPACK_CMAKE_GENERATOR "Unix Makefiles")
SET(CPACK_COMPONENTS_ALL "")
SET(CPACK_COMPONENT_UNSPECIFIED_HIDDEN "TRUE")
SET(CPACK_COMPONENT_UNSPECIFIED_REQUIRED "TRUE")
SET(CPACK_GENERATOR "TGZ")
SET(CPACK_IGNORE_FILES "/\\.git/;\\.gitignore$;/CMakeFiles/;/_CPack_Packages/;cmake_install.cmake;CMakeCache.txt$;install_manifest.txt$;Makefile$;Source\\.tar\\.gz$;Linux\\.tar\\.gz$;moc_.*\\.cxx$;\\.so$;\\.so\\.*;ibus-test$;/rpm/;ibus-qt\\.spec$;CPackSourceConfig\\.cmake$;CPackConfig\\.cmake$;docs/Doxyfile$;docs/man;docs/html;build/")
SET(CPACK_INSTALLED_DIRECTORIES "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo;/")
SET(CPACK_INSTALL_CMAKE_PROJECTS "")
SET(CPACK_INSTALL_PREFIX "/usr")
SET(CPACK_MODULE_PATH "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/cmake")
SET(CPACK_NSIS_DISPLAY_NAME "ibus-qt 1.3.1")
SET(CPACK_NSIS_INSTALLER_ICON_CODE "")
SET(CPACK_NSIS_INSTALLER_MUI_ICON_CODE "")
SET(CPACK_OUTPUT_CONFIG_FILE "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/CPackConfig.cmake")
SET(CPACK_PACKAGE_DEFAULT_LOCATION "/")
SET(CPACK_PACKAGE_DESCRIPTION_FILE "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericDescription.txt")
SET(CPACK_PACKAGE_DESCRIPTION_SUMMARY "ibus-qt built using CMake")
SET(CPACK_PACKAGE_FILE_NAME "ibus-qt-1.3.1-Source")
SET(CPACK_PACKAGE_INSTALL_DIRECTORY "ibus-qt 1.3.1")
SET(CPACK_PACKAGE_INSTALL_REGISTRY_KEY "ibus-qt 1.3.1")
SET(CPACK_PACKAGE_NAME "ibus-qt")
SET(CPACK_PACKAGE_RELOCATABLE "true")
SET(CPACK_PACKAGE_VENDOR "Humanity")
SET(CPACK_PACKAGE_VERSION "1.3.1")
SET(CPACK_PACKAGE_VERSION_MAJOR "1")
SET(CPACK_PACKAGE_VERSION_MINOR "3")
SET(CPACK_PACKAGE_VERSION_PATCH "1")
SET(CPACK_RESOURCE_FILE_LICENSE "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/COPYING")
SET(CPACK_RESOURCE_FILE_README "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericDescription.txt")
SET(CPACK_RESOURCE_FILE_WELCOME "/targets/FREMANTLE_ARMEL/usr/share/cmake-2.6/Templates/CPack.GenericWelcome.txt")
SET(CPACK_SET_DESTDIR "ON")
SET(CPACK_SOURCE_CYGWIN "")
SET(CPACK_SOURCE_GENERATOR "TGZ")
SET(CPACK_SOURCE_IGNORE_FILES "/\\.git/;\\.gitignore$;/CMakeFiles/;/_CPack_Packages/;cmake_install.cmake;CMakeCache.txt$;install_manifest.txt$;Makefile$;Source\\.tar\\.gz$;Linux\\.tar\\.gz$;moc_.*\\.cxx$;\\.so$;\\.so\\.*;ibus-test$;/rpm/;ibus-qt\\.spec$;CPackSourceConfig\\.cmake$;CPackConfig\\.cmake$;docs/Doxyfile$;docs/man;docs/html;build/")
SET(CPACK_SOURCE_INSTALLED_DIRECTORIES "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo;/")
SET(CPACK_SOURCE_OUTPUT_CONFIG_FILE "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/CPackSourceConfig.cmake")
SET(CPACK_SOURCE_PACKAGE_FILE_NAME "ibus-qt-1.3.1-Source")
SET(CPACK_SOURCE_TBZ2 "")
SET(CPACK_SOURCE_TGZ "")
SET(CPACK_SOURCE_TOPLEVEL_TAG "Linux-Source")
SET(CPACK_SOURCE_TZ "")
SET(CPACK_SOURCE_ZIP "")
SET(CPACK_STRIP_FILES "")
SET(CPACK_SYSTEM_NAME "Linux")
SET(CPACK_TOPLEVEL_TAG "Linux-Source")
